==> djbfft-0.50.tar.gz: djbfft-0.50/fftc8_1024.c <==
#include "fftc8.h"

static double roots[] = {
  0.9999811752826011426569904377285677161739
, 0.9999247018391445409216464911963832243506
, 0.9998305817958234220157222749226655145859
, 0.9996988186962042201157656496661721968500
, 0.9995294175010931630797033221567409693598
, 0.9993223845883495008962210111399103525911
, 0.9990777277526453828887819968641261429898
, 0.9987954562051723927147716047591006944432
, 0.9984755805732947522085590384263713301082
, 0.9981181129001492071251558606836062321140
, 0.9977230666441916098485467284287755605433
, 0.9972904566786902161355971401825678211717
, 0.9968202992911657149726293983440371335986
, 0.9963126121827780126272261896697316108763
, 0.9957674144676597939824956425161862154313
, 0.9951847266721968862448369531094799215754
, 0.9945645707342554521191062433890623879592
, 0.9939069700023560415469228132477998214356
, 0.9932119492347945331046010120927827784470
, 0.9924795345987099981567672516611178200108
, 0.9917097536690995228600499310995717595784
, 0.9909026354277800251082370105274337521976
, 0.9900582102622971055059064644647793938596
, 0.9891765099647809734516737380162430639837
, 0.9882575677307494914047925383512565371364
, 0.9873014181578583823998158018450177283203
, 0.9863080972445986478632975243258948530479
, 0.9852776423889412447740184331785477871601
, 0.9842100923869290731938743872398332594066
, 0.9831054874312163271803011546739453386706
, 0.9819638691095552640728481538315649202651
, 0.9807852804032304491261822361342390369739
, 0.9795697656854405344393261098798955052132
, 0.9783173707196276331062400968954989486662
, 0.9770281426577543514858662110857144252620
, 0.9757021300385285444603957664195279716440
, 0.9743393827855758605187216681943645931425
, 0.9729399522055601454677201139037965700244
, 0.9715038909862517755370996218349531511233
, 0.9700312531945439926039842072861002514568
, 0.9685220942744173162210883289834431285217
, 0.9669764710448521090872202259367862730480
, 0.9653944416976893745508438575169030701867
, 0.9637760657954398666864643555078351536631
, 0.9621214042690415954296043162301533683259
, 0.9604305194155658111990351376552656335496
, 0.9587034748958715553746457917668690903737
, 0.9569403357322088649357978869802699694828
, 0.9551411683057707214981577123356394246484
, 0.9533060403541938369167403827397938349041
, 0.9514350209690083695491755689557821707500
, 0.9495281805930366671959360741893450282522
, 0.9475855910177411346533873212314649157949
, 0.9456073253805213257309453865238450864520
, 0.9435934581619603614953014453784386693433
, 0.9415440651830207784125094025995023571856
, 0.9394592236021899119626692458704222131584
, 0.9373390119125749232018995933723808790288
, 0.9351835099389475776422074797424988136309
, 0.9329927988347388877116602555433024982950
, 0.9307669610789837319448723398218081380297
, 0.9285060804732155659371673957159456406234
, 0.9262102421383113419747933884371432823411
, 0.9238795325112867561281831893967882868224
, 0.9215140393420419434653963315480622263672
, 0.9191138516900577439084777893585916788760
, 0.9166790599210426631164570134177923250274
, 0.9142097557035306546350148293935774010447
, 0.9117060320054298514043973250755404989167
, 0.9091679830905223765638847877078063304795
, 0.9065957045149153653329605884237134126506
, 0.9039892931234433315862002972305370487101
, 0.9013488470460220145707460933354787941262
, 0.8986744656939538430419767437334850971686
, 0.8959662497561851559145602819685074912350
, 0.8932243011955153203424164474933979780006
, 0.8904487232447578899521505599180370203448
, 0.8876396204028539477601816172209067692593
, 0.8847970984309377801040070405857408897591
, 0.8819212643483550297127568636603883495084
, 0.8790122264286334778313237108883723441412
, 0.8760700941954066070958442682679904961153
, 0.8730949784182900986360859730828656214301
, 0.8700869911087114186522924044838488439108
, 0.8670462455156926514801956294958485611966
, 0.8639728561215867379181470543455525270743
, 0.8608669386377672793445838767919507564613
, 0.8577286100002720699022699842847701370425
, 0.8545579883654005207678622757156412315482
, 0.8513551931052651422612903117258743556752
, 0.8481203448032972512791335629489720926244
, 0.8448535652497070732595712051049570977198
, 0.8415549774368984096034995198422270646026
, 0.8382247055548380431869968558042860626362
, 0.8348628749863800563044013830288509569496
, 0.8314696123025452370787883776179057567385
, 0.8280450452577557520675275919240992974059
, 0.8245893027850252644748037370848904463286
, 0.8211025149911046790604308203298999031279
, 0.8175848131515836965049208841306338094710
, 0.8140363297059483616545166896872007386115
, 0.8104571982525947917267034342445271670501
, 0.8068475535437992722065143125084730510426
, 0.8032075314806449098066765129631419238795
, 0.7995372691079050335002462322515077643195
, 0.7958369046088835362627919154816773610504
, 0.7921065773002123517823428786210334566942
, 0.7883464276266062620091647053596892826565
, 0.7845565971555752330238925746397839911870
, 0.7807372285720944783015884837795336966664
, 0.7768884656732324500408279830138537082772
, 0.7730104533627369608109066097584698009710
, 0.7691033376455796393466260688578576671915
, 0.7651672656224589258888159990649059180489
, 0.7612023854842618140297098355118759758054
, 0.7572088465064845475754640536057844730404
, 0.7531867990436124824834304856149119103704
, 0.7491363945234593254692032567668843148057
, 0.7450577854414659624079073102652695805364
, 0.7409511253549590911756168974951627297289
, 0.7368165688773698750901325201727469468679
, 0.7326542716724128346155466488994934632929
, 0.7284643904482251964920354375100570986875
, 0.7242470829514669209410692432905531674831
, 0.7200025079613816290766829987842242033653
, 0.7157308252838186541255326234552024122146
, 0.7114321957452164415221302897745546729364
, 0.7071067811865475244008443621048490392848
, 0.7027547444572253024529144208959899415321
, 0.6983762494089728535548135030617225398363
, 0.6939714608896540090037343890191158870916
, 0.6895405447370669246167306299574847028455
, 0.6850836677727003813620525448786688535463
, 0.6806009977954530505944304644563996185348
, 0.6760927035753159603604192276581525580927
, 0.6715589548470184006253768504274218032287
, 0.6669999223036375066501542217927266025220
, 0.6624157775901717611130698169566881852974
, 0.6578066932970786569311822637300037965084
, 0.6531728429537767640842030136563054150768
, 0.6485144010221124450845605508348932123722
, 0.6438315428897914650680860631769553884419
, 0.6391244448637757438014881927921738391133
, 0.6343932841636454982151716132254933706757
, 0.6296382389149270253729813407145820848289
, 0.6248594881423863770840728162810527125578
, 0.6200572117632891786462681913114239630541
, 0.6152315905806268454849135634139842776594
, 0.6103828062763094527163521517406882689737
, 0.6055110414043255139206269413298796581826
, 0.6006164793838689266538758955455595386439
, 0.5956993044924333434670365288299698895119
, 0.5907597018588742284238879082605695714561
, 0.5857978574564388603280808381186622857671
, 0.5808139580957645450755952716785138763990
, 0.5758081914178453007459724538157308417760
, 0.5707807458869672802326528638849623650065
, 0.5657318107836131973897650113692660904743
, 0.5606615761973360238397102231455323464061
, 0.5555702330196022247428308139485328743749
, 0.5504579729366048029772898925285391908408
, 0.5453249884220464223139873471738261971863
, 0.5401714727298928812978454797368391243804
, 0.5349976198870972106630769046370179155602
, 0.5298036246862946682160546712352691063333
, 0.5245896826784689062150984639335456725563
, 0.5193559901655895873618299320920460363301
, 0.5141027441932217265936938389688157726080
, 0.5088301425431070369317493243516528643706
, 0.5035383837257175586918670712604959834511
, 0.4982276669727818524109838693598428202796
, 0.4928981922297840368730266887588092682396
, 0.4875501601484359546414850273076499075501
, 0.4821837720791227485173444807974086112396
, 0.4767992300633221333421581174135755721060
, 0.4713967368259976485563876259052543776574
, 0.4659764957679661779027560648877787034269
, 0.4605387109582400236331814867414884243654
, 0.4550835871263438235358692678967193602180
, 0.4496113296546066000462945794242270758831
, 0.4441221445704292316420694179834663691061
, 0.4386162385385276376470257375461343598431
, 0.4330938188531519684842226384895773616555
, 0.4275550934302820943209668568887985343045
, 0.4220002707997996859412879413320511405711
, 0.4164295600976371825625989107894802468556
, 0.4108431710579039421834666749289471041367
, 0.4052413140049898709084813055050524665119
, 0.3996241998456468285441170307420208607299
, 0.3939920400610481085961886608903134244856
, 0.3883450466988262916249935406705281014962
, 0.3826834323650897717284599840303988667613
, 0.3770074102164182567265678231998572323015
, 0.3713171939518375434119349670219232661775
, 0.3656129978047738700117459086069781700085
, 0.3598950365349881487751045723267564202023
, 0.3541635254204903823573957961389289436032
, 0.3484186802494345684193085876948116364531
, 0.3426607173119943975927819825612868796115
, 0.3368898533922200506892532126191475704777
, 0.3311063057598764017371907372666501496458
, 0.3253102921622629341359547080141967703657
, 0.3195020308160156779015182715397565772982
, 0.3136817403988914766564788459941003099933
, 0.3078496400415348936820636455585202015094
, 0.3020059493192280670034632317324243912848
, 0.2961508882436238241217861277826588797865
, 0.2902846772544623676361923758173952746914
, 0.2844075372112718436183106149398162274615
, 0.2785196893850531052078485259570194793626
, 0.2726213554499489844933474772922102408041
, 0.2667127574748983863252865151164363940421
, 0.2607941179152755182801865090847883426487
, 0.2548656596045145715539807788247035490779
, 0.2489276057457201681106828162729877050769
, 0.2429801799032638899482741620774711183209
, 0.2370236059943672068677359145212644641039
, 0.2310581082806711196432360184727066652304
, 0.2250839113597928359916421198633534633451
, 0.2191012401568697972277375474973577988483
, 0.2131103199160913739677575178515008423979
, 0.2071113761922185497081160197866674167674
, 0.2011046348420919115584435458820671774655
, 0.1950903220161282678482848684770222409276
, 0.1890686641498062127549978370874602018495
, 0.1830398879551409585165325784769200138775
, 0.1770042204121487561968398439291657307197
, 0.1709618887603012263636423572082635319663
, 0.1649131204899699214181891132844101245585
, 0.1588581433338614416843853596530813017855
, 0.1527971852584434277203366125438313132217
, 0.1467304744553617516588501296467178197062
, 0.1406582393328492307147888464071430911197
, 0.1345807085071261863163584092539792556314
, 0.1284981107937931726244155891727575476975
, 0.1224106751992161984987044741509457875752
, 0.1163186309119047672525443194705125409238
, 0.1102222072938830588078991402156777252744
, 0.1041216338720545791209438800601790207959
, 0.0980171403295606019941955638886418458611
, 0.0919089564971327286249909790776994870092
, 0.0857973123444398904615563321468461719405
, 0.0796824379714301211471206559958854013640
, 0.0735645635996674235294656215752343218133
, 0.0674439195636640578979724218744933647691
, 0.0613207363022085777826145929172350071940
, 0.0551952443496899398094475256977309118981
, 0.0490676743274180142549549769426826583147
, 0.0429382569349408230771245402817839553939
, 0.0368072229413588323243326909279513010552
, 0.0306748031766366259340210275652237129977
, 0.0245412285229122880317345294592829250655
, 0.0184067299058048209273663130148401265505
, 0.0122715382857199260794082619510032121404
, 0.0061358846491544753596402345903725809171
} ;

FFTC8(fftc8_1024,fftc8_512,fftc8_256,roots - 256,256)

==> djbfft-0.60.tar.gz: djbfft-0.60/fftc4_1024.c <==
#include "fftc4.h"

FFTC4(fftc4_1024,fftc4_512,fftc4_256,fftc4_roots1024 - 256,256)
FFTC4_UN(fftc4_un1024,fftc4_un512,fftc4_un256,fftc4_roots1024 - 256,256)

float fftc4_roots1024[] = {
  0.9999811752826011426569904377285677161739
, 0.9999247018391445409216464911963832243506
, 0.9998305817958234220157222749226655145859
, 0.9996988186962042201157656496661721968500
, 0.9995294175010931630797033221567409693598
, 0.9993223845883495008962210111399103525911
, 0.9990777277526453828887819968641261429898
, 0.9987954562051723927147716047591006944432
, 0.9984755805732947522085590384263713301082
, 0.9981181129001492071251558606836062321140
, 0.9977230666441916098485467284287755605433
, 0.9972904566786902161355971401825678211717
, 0.9968202992911657149726293983440371335986
, 0.9963126121827780126272261896697316108763
, 0.9957674144676597939824956425161862154313
, 0.9951847266721968862448369531094799215754
, 0.9945645707342554521191062433890623879592
, 0.9939069700023560415469228132477998214356
, 0.9932119492347945331046010120927827784470
, 0.9924795345987099981567672516611178200108
, 0.9917097536690995228600499310995717595784
, 0.9909026354277800251082370105274337521976
, 0.9900582102622971055059064644647793938596
, 0.9891765099647809734516737380162430639837
, 0.9882575677307494914047925383512565371364
, 0.9873014181578583823998158018450177283203
, 0.9863080972445986478632975243258948530479
, 0.9852776423889412447740184331785477871601
, 0.9842100923869290731938743872398332594066
, 0.9831054874312163271803011546739453386706
, 0.9819638691095552640728481538315649202651
, 0.9807852804032304491261822361342390369739
, 0.9795697656854405344393261098798955052132
, 0.9783173707196276331062400968954989486662
, 0.9770281426577543514858662110857144252620
, 0.9757021300385285444603957664195279716440
, 0.9743393827855758605187216681943645931425
, 0.9729399522055601454677201139037965700244
, 0.9715038909862517755370996218349531511233
, 0.9700312531945439926039842072861002514568
, 0.9685220942744173162210883289834431285217
, 0.9669764710448521090872202259367862730480
, 0.9653944416976893745508438575169030701867
, 0.9637760657954398666864643555078351536631
, 0.9621214042690415954296043162301533683259
, 0.9604305194155658111990351376552656335496
, 0.9587034748958715553746457917668690903737
, 0.9569403357322088649357978869802699694828
, 0.9551411683057707214981577123356394246484
, 0.9533060403541938369167403827397938349041
, 0.9514350209690083695491755689557821707500
, 0.9495281805930366671959360741893450282522
, 0.9475855910177411346533873212314649157949
, 0.9456073253805213257309453865238450864520
, 0.9435934581619603614953014453784386693433
, 0.9415440651830207784125094025995023571856
, 0.9394592236021899119626692458704222131584
, 0.9373390119125749232018995933723808790288
, 0.9351835099389475776422074797424988136309
, 0.9329927988347388877116602555433024982950
, 0.9307669610789837319448723398218081380297
, 0.9285060804732155659371673957159456406234
, 0.9262102421383113419747933884371432823411
, 0.9238795325112867561281831893967882868224
, 0.9215140393420419434653963315480622263672
, 0.9191138516900577439084777893585916788760
, 0.9166790599210426631164570134177923250274
, 0.9142097557035306546350148293935774010447
, 0.9117060320054298514043973250755404989167
, 0.9091679830905223765638847877078063304795
, 0.9065957045149153653329605884237134126506
, 0.9039892931234433315862002972305370487101
, 0.9013488470460220145707460933354787941262
, 0.8986744656939538430419767437334850971686
, 0.8959662497561851559145602819685074912350
, 0.8932243011955153203424164474933979780006
, 0.8904487232447578899521505599180370203448
, 0.8876396204028539477601816172209067692593
, 0.8847970984309377801040070405857408897591
, 0.8819212643483550297127568636603883495084
, 0.8790122264286334778313237108883723441412
, 0.8760700941954066070958442682679904961153
, 0.8730949784182900986360859730828656214301
, 0.8700869911087114186522924044838488439108
, 0.8670462455156926514801956294958485611966
, 0.8639728561215867379181470543455525270743
, 0.8608669386377672793445838767919507564613
, 0.8577286100002720699022699842847701370425
, 0.8545579883654005207678622757156412315482
, 0.8513551931052651422612903117258743556752
, 0.8481203448032972512791335629489720926244
, 0.8448535652497070732595712051049570977198
, 0.8415549774368984096034995198422270646026
, 0.8382247055548380431869968558042860626362
, 0.8348628749863800563044013830288509569496
, 0.8314696123025452370787883776179057567385
, 0.8280450452577557520675275919240992974059
, 0.8245893027850252644748037370848904463286
, 0.8211025149911046790604308203298999031279
, 0.8175848131515836965049208841306338094710
, 0.8140363297059483616545166896872007386115
, 0.8104571982525947917267034342445271670501
, 0.8068475535437992722065143125084730510426
, 0.8032075314806449098066765129631419238795
, 0.7995372691079050335002462322515077643195
, 0.7958369046088835362627919154816773610504
, 0.7921065773002123517823428786210334566942
, 0.7883464276266062620091647053596892826565
, 0.7845565971555752330238925746397839911870
, 0.7807372285720944783015884837795336966664
, 0.7768884656732324500408279830138537082772
, 0.7730104533627369608109066097584698009710
, 0.7691033376455796393466260688578576671915
, 0.7651672656224589258888159990649059180489
, 0.7612023854842618140297098355118759758054
, 0.7572088465064845475754640536057844730404
, 0.7531867990436124824834304856149119103704
, 0.7491363945234593254692032567668843148057
, 0.7450577854414659624079073102652695805364
, 0.7409511253549590911756168974951627297289
, 0.7368165688773698750901325201727469468679
, 0.7326542716724128346155466488994934632929
, 0.7284643904482251964920354375100570986875
, 0.7242470829514669209410692432905531674831
, 0.7200025079613816290766829987842242033653
, 0.7157308252838186541255326234552024122146
, 0.7114321957452164415221302897745546729364
, 0.7071067811865475244008443621048490392848
, 0.7027547444572253024529144208959899415321
, 0.6983762494089728535548135030617225398363
, 0.6939714608896540090037343890191158870916
, 0.6895405447370669246167306299574847028455
, 0.6850836677727003813620525448786688535463
, 0.6806009977954530505944304644563996185348
, 0.6760927035753159603604192276581525580927
, 0.6715589548470184006253768504274218032287
, 0.6669999223036375066501542217927266025220
, 0.6624157775901717611130698169566881852974
, 0.6578066932970786569311822637300037965084
, 0.6531728429537767640842030136563054150768
, 0.6485144010221124450845605508348932123722
, 0.6438315428897914650680860631769553884419
, 0.6391244448637757438014881927921738391133
, 0.6343932841636454982151716132254933706757
, 0.6296382389149270253729813407145820848289
, 0.6248594881423863770840728162810527125578
, 0.6200572117632891786462681913114239630541
, 0.6152315905806268454849135634139842776594
, 0.6103828062763094527163521517406882689737
, 0.6055110414043255139206269413298796581826
, 0.6006164793838689266538758955455595386439
, 0.5956993044924333434670365288299698895119
, 0.5907597018588742284238879082605695714561
, 0.5857978574564388603280808381186622857671
, 0.5808139580957645450755952716785138763990
, 0.5758081914178453007459724538157308417760
, 0.5707807458869672802326528638849623650065
, 0.5657318107836131973897650113692660904743
, 0.5606615761973360238397102231455323464061
, 0.5555702330196022247428308139485328743749
, 0.5504579729366048029772898925285391908408
, 0.5453249884220464223139873471738261971863
, 0.5401714727298928812978454797368391243804
, 0.5349976198870972106630769046370179155602
, 0.5298036246862946682160546712352691063333
, 0.5245896826784689062150984639335456725563
, 0.5193559901655895873618299320920460363301
, 0.5141027441932217265936938389688157726080
, 0.5088301425431070369317493243516528643706
, 0.5035383837257175586918670712604959834511
, 0.4982276669727818524109838693598428202796
, 0.4928981922297840368730266887588092682396
, 0.4875501601484359546414850273076499075501
, 0.4821837720791227485173444807974086112396
, 0.4767992300633221333421581174135755721060
, 0.4713967368259976485563876259052543776574
, 0.4659764957679661779027560648877787034269
, 0.4605387109582400236331814867414884243654
, 0.4550835871263438235358692678967193602180
, 0.4496113296546066000462945794242270758831
, 0.4441221445704292316420694179834663691061
, 0.4386162385385276376470257375461343598431
, 0.4330938188531519684842226384895773616555
, 0.4275550934302820943209668568887985343045
, 0.4220002707997996859412879413320511405711
, 0.4164295600976371825625989107894802468556
, 0.4108431710579039421834666749289471041367
, 0.4052413140049898709084813055050524665119
, 0.3996241998456468285441170307420208607299
, 0.3939920400610481085961886608903134244856
, 0.3883450466988262916249935406705281014962
, 0.3826834323650897717284599840303988667613
, 0.3770074102164182567265678231998572323015
, 0.3713171939518375434119349670219232661775
, 0.3656129978047738700117459086069781700085
, 0.3598950365349881487751045723267564202023
, 0.3541635254204903823573957961389289436032
, 0.3484186802494345684193085876948116364531
, 0.3426607173119943975927819825612868796115
, 0.3368898533922200506892532126191475704777
, 0.3311063057598764017371907372666501496458
, 0.3253102921622629341359547080141967703657
, 0.3195020308160156779015182715397565772982
, 0.3136817403988914766564788459941003099933
, 0.3078496400415348936820636455585202015094
, 0.3020059493192280670034632317324243912848
, 0.2961508882436238241217861277826588797865
, 0.2902846772544623676361923758173952746914
, 0.2844075372112718436183106149398162274615
, 0.2785196893850531052078485259570194793626
, 0.2726213554499489844933474772922102408041
, 0.2667127574748983863252865151164363940421
, 0.2607941179152755182801865090847883426487
, 0.2548656596045145715539807788247035490779
, 0.2489276057457201681106828162729877050769
, 0.2429801799032638899482741620774711183209
, 0.2370236059943672068677359145212644641039
, 0.2310581082806711196432360184727066652304
, 0.2250839113597928359916421198633534633451
, 0.2191012401568697972277375474973577988483
, 0.2131103199160913739677575178515008423979
, 0.2071113761922185497081160197866674167674
, 0.2011046348420919115584435458820671774655
, 0.1950903220161282678482848684770222409276
, 0.1890686641498062127549978370874602018495
, 0.1830398879551409585165325784769200138775
, 0.1770042204121487561968398439291657307197
, 0.1709618887603012263636423572082635319663
, 0.1649131204899699214181891132844101245585
, 0.1588581433338614416843853596530813017855
, 0.1527971852584434277203366125438313132217
, 0.1467304744553617516588501296467178197062
, 0.1406582393328492307147888464071430911197
, 0.1345807085071261863163584092539792556314
, 0.1284981107937931726244155891727575476975
, 0.1224106751992161984987044741509457875752
, 0.1163186309119047672525443194705125409238
, 0.1102222072938830588078991402156777252744
, 0.1041216338720545791209438800601790207959
, 0.0980171403295606019941955638886418458611
, 0.0919089564971327286249909790776994870092
, 0.0857973123444398904615563321468461719405
, 0.0796824379714301211471206559958854013640
, 0.0735645635996674235294656215752343218133
, 0.0674439195636640578979724218744933647691
, 0.0613207363022085777826145929172350071940
, 0.0551952443496899398094475256977309118981
, 0.0490676743274180142549549769426826583147
, 0.0429382569349408230771245402817839553939
, 0.0368072229413588323243326909279513010552
, 0.0306748031766366259340210275652237129977
, 0.0245412285229122880317345294592829250655
, 0.0184067299058048209273663130148401265505
, 0.0122715382857199260794082619510032121404
, 0.0061358846491544753596402345903725809171
} ;
